#############################################################
#
# mksquashfs to build target squashfs filesystems
#
#############################################################
SQUASHFS2_DIR=$(BUILD_DIR)/squashfs2.0r2
SQUASHFS2_SOURCE=squashfs2.0-r2.tar.gz
SQUASHFS2_SITE=http://aleron.dl.sourceforge.net/sourceforge/squashfs

FBOXFW_DIR=$(BUILD_DIR)/fboxfw-03.14
FBOXFW_SOURCE=fritz.box_fon_wlan.08.03.14.image
FBOXFW_SITE=ftp://ftp.avm.de/cardware/fritzbox.fon_wlan/firmware

$(DL_DIR)/$(SQUASHFS2_SOURCE):
	$(WGET) -P $(DL_DIR) $(SQUASHFS2_SITE)/$(SQUASHFS2_SOURCE)
$(DL_DIR)/$(FBOXFW_SOURCE):
	$(WGET) --passive-ftp -P $(DL_DIR) $(FBOXFW_SITE)/$(FBOXFW_SOURCE)

$(SQUASHFS2_DIR): $(DL_DIR)/$(SQUASHFS2_SOURCE) #$(SQUASHFS2_PATCH)
	zcat $(DL_DIR)/$(SQUASHFS2_SOURCE) | tar -C $(BUILD_DIR) -xvf -
	#toolchain/patch-kernel.sh $(SQUASHFS2_DIR) target/fritz/ squashfs.patch
$(FBOXFW_DIR)/root-fs: $(DL_DIR)/$(FBOXFW_SOURCE)
	-mkdir -p $(FBOXFW_DIR)/root-fs
	tar -C $(FBOXFW_DIR) -xvf $(DL_DIR)/$(FBOXFW_SOURCE)
	-mkdir $(BUILD_DIR)/fboxmnt
	sudo mount -o loop -t squashfs $(FBOXFW_DIR)/var/tmp/filesystem.image $(BUILD_DIR)/fboxmnt
	cp -a $(BUILD_DIR)/fboxmnt/* $(FBOXFW_DIR)/root-fs
	sudo umount $(BUILD_DIR)/fboxmnt
	rmdir $(BUILD_DIR)/fboxmnt

$(SQUASHFS2_DIR)/squashfs-tools/mksquashfs: $(SQUASHFS2_DIR)
	$(MAKE) -C $(SQUASHFS2_DIR)/squashfs-tools;

squashfs2: $(SQUASHFS2_DIR)/squashfs-tools/mksquashfs

squashfs2-source: $(DL_DIR)/$(SQUASHFS2_SOURCE)

squashfs2-clean:
	-$(MAKE) -C $(SQUASHFS2_DIR)/squashfs-tools clean

squashfs2-dirclean:
	rm -rf $(SQUASHFS2_DIR)

fboxfw: $(FBOXFW_DIR)/root-fs

fboxfw-source: $(DL_DIR)/$(FBOXFW_SOURCE)

fboxfw-dirclean:
	rm -rf $(FBOXFW_DIR)

#############################################################
#
# Build the fritzbox root filesystem image
#
#############################################################

fritzboxroot: $(SQUASHFS2_DIR)/squashfs-tools/mksquashfs fboxfw
	rm -rf $(BUILD_DIR)/tmproot
	mkdir $(BUILD_DIR)/tmproot
	cp -a $(FBOXFW_DIR)/root-fs/* $(BUILD_DIR)/tmproot
	# remove original busybox
	find $(BUILD_DIR)/tmproot -ls | \
	  awk '/busybox/ {print $$11}' | xargs rm
	tar cf - -C $(TARGET_DIR) ./lib | tar xvf - -C $(BUILD_DIR)/tmproot
	tar cf - -C  $(TARGET_DIR) \
	  $$(cd $(TARGET_DIR) ; find . -ls | awk '/busybox/ {print $$11}') | \
	  tar xvf - -C $(BUILD_DIR)/tmproot
	( cd $(BUILD_DIR)/tmproot/lib && \
	  rm -f libncurses.so* libthread_db* )
	-find $(BUILD_DIR)/tmproot -type f -perm +111 | \
	  xargs $(STRIP) 2>/dev/null || true;
	$(SQUASHFS2_DIR)/squashfs-tools/mksquashfs $(BUILD_DIR)/tmproot \
	  filesystem.image -noappend -root-owned
	#rm -rf $(BUILD_DIR)/tmproot

fritzboxroot-source: squashfs2-source fboxfw

fritzboxroot-clean:
	-$(MAKE) -C $(SQUASHFS2_DIR) clean

fritzboxroot-dirclean:
	rm -rf $(SQUASHFS2_DIR)

